diff mbox series

[U-Boot,1/1] disk: part: fix typo

Message ID 20170829163659.2996-1-xypron.glpk@gmx.de
State Accepted
Commit 5eae466ea1ebd79c8033d4686242d5971a86bf74
Delegated to: Tom Rini
Headers show
Series [U-Boot,1/1] disk: part: fix typo | expand

Commit Message

Heinrich Schuchardt Aug. 29, 2017, 4:36 p.m. UTC
%s/Desriptor/Descriptor/g

Fix lines over 80 characters with said typo.

Signed-off-by: Heinrich Schuchardt <xypron.glpk@gmx.de>
---
 disk/part_mac.c | 12 +++++++++---
 1 file changed, 9 insertions(+), 3 deletions(-)

Comments

Tom Rini Sept. 4, 2017, 12:42 a.m. UTC | #1
On Tue, Aug 29, 2017 at 06:36:59PM +0200, Heinrich Schuchardt wrote:

> %s/Desriptor/Descriptor/g
> 
> Fix lines over 80 characters with said typo.
> 
> Signed-off-by: Heinrich Schuchardt <xypron.glpk@gmx.de>

Applied to u-boot/master, thanks!
diff mbox series

Patch

diff --git a/disk/part_mac.c b/disk/part_mac.c
index b6c082e7e1..d597dcf00a 100644
--- a/disk/part_mac.c
+++ b/disk/part_mac.c
@@ -47,7 +47,10 @@  static int part_test_mac(struct blk_desc *dev_desc)
 	ulong i, n;
 
 	if (part_mac_read_ddb (dev_desc, ddesc)) {
 		/* error reading Driver Desriptor Block, or no valid Signature */
 		return (-1);
 	}
 
@@ -71,7 +74,10 @@  static void part_print_mac(struct blk_desc *dev_desc)
 	ldiv_t mb, gb;
 
 	if (part_mac_read_ddb (dev_desc, ddesc)) {
 		/* error reading Driver Desriptor Block, or no valid Signature */
 		return;
 	}
 
@@ -153,7 +159,7 @@  static int part_mac_read_ddb(struct blk_desc *dev_desc,
 			     mac_driver_desc_t *ddb_p)
 {
 	if (blk_dread(dev_desc, 0, 1, (ulong *)ddb_p) != 1) {
-		printf ("** Can't read Driver Desriptor Block **\n");
+		printf("** Can't read Driver Descriptor Block **\n");
 		return (-1);
 	}
@@ -47,7 +47,10 @@  static int part_test_mac(struct blk_desc *dev_desc)
 
 	if (part_mac_read_ddb (dev_desc, ddesc)) {
-		/* error reading Driver Desriptor Block, or no valid Signature */
+		/*
+		 * error reading Driver Descriptor Block,
+		 * or no valid Signature
+		 */
 		return (-1);
 	}
@@ -71,7 +74,10 @@  static void part_print_mac(struct blk_desc *dev_desc)
 
 	if (part_mac_read_ddb (dev_desc, ddesc)) {
-		/* error reading Driver Desriptor Block, or no valid Signature */
+		/*
+		 * error reading Driver Descriptor Block,
+		 * or no valid Signature
+		 */
 		return;
 	}